/*
 * IRC - Internet Relay Chat, ircd/m_rahash.c
 * Copyright (C) 1990 Jarkko Oikarinen and
 *                    University of Oulu, Computing Center
 *
 * See file AUTHORS in IRC package for additional names of
 * the programmers.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 1, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * $Id: m_rahash.c,v 1.5 2003/06/23 09:21:58 sirvulcan Exp $
 */

#include "channel.h"
#include "config.h"
#include "client.h"
#include "handlers.h"
#include "hash.h"
#include "ircd.h"
#include "ircd_defs.h"
#include "ircd_features.h"
#include "ircd_relay.h"
#include "ircd_reply.h"
#include "ircd_string.h"
#include "ircd_snprintf.h"
#include "ircd_alloc.h"
#include "list.h"
#include "msg.h"
#include "numeric.h"
#include "numnicks.h"
#include "querycmds.h"
#include "send.h"
#include "s_conf.h"
#include "s_user.h"
#include "s_debug.h"
#include "userload.h"
#include "patchlevel.h"

#include <string.h>
#include <ctype.h>
#include <stdlib.h>

int m_rahash(struct Client *cptr, struct Client *sptr, int parc, char *parv[])
{
  if (!HasPriv(sptr, PRIV_RAHASH))
    return send_reply(sptr, ERR_NOPRIVILEGES);

  if (parc < 2) {
     send_reply(sptr, ERR_NEEDMOREPARAMS, "RAHASH");
     return 0;
  }
  
  if (!FindServer(parv[1])) {
   send_reply(sptr, ERR_NOSUCHSERVER, parv[1]);
   return 0;
  }

  send_reply(sptr, RPL_RAHASHING, "ircd.conf", parv[1]);
  sendto_opmask_butone(0, SNO_OLDSNO, "%C is remote rehashing %s Server config file", sptr, parv[1]);

  sendcmdto_serv_butone(sptr, CMD_RAHASH, cptr, "%s", parv[1]);  
  return 0;
}

int ms_rahash(struct Client *cptr, struct Client *sptr, int parc, char *parv[])
{
  int flag = 0;

  if ((parv[1] = cli_name(&me))) {
    sendto_opmask_butone(0, SNO_OLDSNO, "%C is remote rehashing Server config file", sptr);
    return rehash(sptr, flag);
  } else {
    sendto_opmask_butone(0, SNO_OLDSNO, "%C is remote rehashing %s Server config file", sptr, parv[1]);
    return 0;
  }
}
